%This is the code to generate inputs for the Stata file stockrsqsigeps.dta
%The input is stock-level return data and factor return data
%The input variables are: id, time, stockret, mktrf, smb, hml, mom) and come from CRSP
%The output files are converted into Stata and combined into one file stockrsqsigeps.dta

clear all

load stockrsq_new.txt
data=stockrsq_new;

clear stockrsq_new

data=sortrows(data,[1 2]);

N=data(end,1); %Number of funds
T=max(data(:,2)); %Number of time periods
RSQ=ones(N,T-11)*(-99); %RSQ with market return
BETA=ones(N,T-11)*(-99); %Market beta
SIGEPS=ones(N,T-11)*(-99); %Sigma epsilon
BETASQVOL=ones(N,T-11)*(-99); %Market beta

for i=1:N
    i
    clear a A
    a=find(data(:,1)==i);
    A=data(a,:);
    for t=1:T-11
        clear b B a1 a2 a3 a4 a5 exret
        b=find(A(:,2)>=t&A(:,2)<=t+11);
        if (length(b)>=9 & A(b(end),2)==t+11)
            B=A(b,:);
            exret=B(:,3)-B(:,8);
            c=length(B(:,1));
            [a1,a2,a3,a4,a5]=regress(exret,[ones(c,1) B(:,4)]);
            RSQ(i,t)=a5(1);
            BETA(i,t)=a1(2);
            SIGEPS(i,t)=std(a3);
            BETASQVOL(i,t)=((a1(2))^2)*(std(B(:,4)))^2;
        else
            continue
        end;
    end;
 end;

RSQ=RSQ';
RSQ=RSQ(:);

for i=1:N
   RSQ((i-1)*(T-11)+1:i*(T-11),2)=ones(T-11,1)*i;
   RSQ((i-1)*(T-11)+1:i*(T-11),3)=(12:1:T)';
end;

BETA=BETA';
BETA=BETA(:);

for i=1:N
   BETA((i-1)*(T-11)+1:i*(T-11),2)=ones(T-11,1)*i;
   BETA((i-1)*(T-11)+1:i*(T-11),3)=(12:1:T)'; 
end;

SIGEPS=SIGEPS';
SIGEPS=SIGEPS(:);

for i=1:N
   SIGEPS((i-1)*(T-11)+1:i*(T-11),2)=ones(T-11,1)*i;
   SIGEPS((i-1)*(T-11)+1:i*(T-11),3)=(12:1:T)'; 
end;

BETASQVOL=BETASQVOL';
BETASQVOL=BETASQVOL(:);

for i=1:N
   BETASQVOL((i-1)*(T-11)+1:i*(T-11),2)=ones(T-11,1)*i;
   BETASQVOL((i-1)*(T-11)+1:i*(T-11),3)=(12:1:T)'; 
end;

save rsquaredstock_new.txt RSQ -ascii -tabs

save betastock_new.txt BETA -ascii -tabs

save sigepsstock_new.txt SIGEPS -ascii -tabs

save betasqvolstock_new.txt BETASQVOL -ascii -tabs

quit;