clear all

*Loading the holdings data obtained from Thomson Reuters (on WRDS)
*Due to file size restriction the data are sepearted into different time periods 
*The input variables are: fundno, shares, permno, yearm

use "/Users/mkacperc/Stijn/Revision/Data/weight8084.dta"
append using "/Users/mkacperc/Stijn/Revision/Data/weight8589.dta"
append using "/Users/mkacperc/Stijn/Revision/Data/weight9094.dta"
append using "/Users/mkacperc/Stijn/Revision/Data/weight9599.dta"
append using "/Users/mkacperc/Stijn/Revision/Data/weight0003.dta"
append using "/Users/mkacperc/Stijn/Revision/Data/weight0407.dta"

keep  fundno shares permno yearm

*Merging the time dimension that helps to manipulate the output variables in Matlab 
*The text files outputs from this file are used in Matlab codes covarindeps.m and covarsue31.m)
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/time.dta",nokeep
tab _merge

drop _merge yearm

duplicates drop fundno permno time,force

sort fundno time
by fundno: gen T=time[_n+1] if time==time[_n-1] & time<time[_n+1]

by fundno time: egen T2=min(T)
replace T2=T2-1

drop T
rename T2 T

replace T=time if T==. & time~=.

*Merging the stock price data from CRSP
sort permno time
merge permno time using "/Users/mkacperc/Stijn/Revision/Data/stockprices.dta",nokeep
tab _merge
drop _merge

gen double id=fundno*100000+permno

drop if permno==.

tsset id time

tsfill

sort id time
by id: egen check=max(time)
replace T=check if T>check & T~=.

by id: replace T=T[_n-1] if T==. & T[_n-1]~=.

drop check

drop if time>T

by id: egen meanperm=mean(permno)
by id: egen meanfundno=mean(fundno)

replace permno=meanperm if permno==. & meanperm~=.
replace fundno=meanfundno if fundno==. & meanfundno~=.

drop meanperm meanfundno T

*Merging stock returns data from CRSP
sort permno time
merge permno time using "/Users/mkacperc/Stijn/Revision/Data/stockreturns.dta",nokeep
tab _merge
drop _merge

*Merging market weights data for each stock (based on mkt capitalization of each stock in the market)
sort permno time
merge permno time using "/Users/mkacperc/Stijn/Revision/Data/mktweights.dta",nokeep
tab _merge
drop _merge yearm

*Generating stock market equity
gen value=shares*prc

tsset id time
replace value=L.value*(1+ret) if value==. & L.value~=. & ret~=.

*Generating market weight
sort fundno time
by fundno time: egen totval=sum(value)
gen weight=value/totval

drop value totval shares prc mktrf beta Wbeta ret 

tsset id time

*Generating weight difference between stock weight and corresponding market weight
gen weightdiff=weight-weightmkt

*Merging SUE data
gen year=int(yearm/100)
gen month=yearm-year*100
gen qtr=int(month/3)
gen yearq=year*10+qtr
drop qtr year month

sort permno yearq
merge permno yearq using "/Users/mkacperc/Stijn/Revision/Data/SUE_new.dta",nokeep
tab _merge
drop _merge

*Merging industrial production data
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/indprod.dta",nokeep
tab _merge
drop _merge

*Lagging the weight difference for the covariance calculation
tsset id time
gen Lweightdiff=L.weightdiff

keep id time Lweightdiff WSUE31 f1indprod

save "/Users/mkacperc/Stijn/Revision/Data/corr3_new.dta",replace

*Generating text files to be used in Matlab codes (macro1.txt and sue31.txt)

clear all
use "/Users/mkacperc/Stijn/Revision/Data/corr3_new.dta"

keep id time Lweightdiff WSUE31
order id time Lweightdiff WSUE31

sort id time
outsheet using  "/Users/mkacperc/Stijn/Revision/Data/sue31.txt"

clear all
use "/Users/mkacperc/Stijn/Revision/Data/corr3_new.dta"

keep id time Lweightdiff f1indprod
order id time Lweightdiff f1indprod

sort id time
outsheet using  "/Users/mkacperc/Stijn/Revision/Data/macro1.txt"
