% A Rational Theory of Mutual Funds' Attention Allocation
% Numerical example - May 2014

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PRELIMINARIES %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;

% primitives that are not being calibrated
ex_12       = 1; % av. supply of the risks 1 & 2, \bar{x}_1 and \bar{x}_2
r           = 1.01; % gross riskfree rate
informed    = 0.20; % chi (fraction of informed agents); robustness to value of 0.10
PARAMS_fix  = [ex_12; r; informed];

% parameters for simulation
funds       = 2500; % number of funds for the simulation
funds_inf   = round(informed.*funds); % number of informed funds
funds_un    = funds - funds_inf; % number of uninformed funds
draws       = 10000; % number of 'periods'
lastinf     = round(funds*informed);
PARAMS_sim  = [funds; funds_inf; funds_un; draws; lastinf];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% CALIBRATION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% choose other paremeters
PARAMS(1)   = 220;             % W_0 220
PARAMS(2)   = 0.175;           % set rho for expansions here
PARAMS(3)   = 1*PARAMS(2);     % set rho for recessions here; switch between 1 and 2 for effect of change in risk aversion
PARAMS(4)   = 0.70;            % b_1
PARAMS(5)   = 1.0;             % b_2
PARAMS(6)   = 0.55;            % variance z1/z2: \sigma_1, \sigma_2
PARAMS(7)   = 0.25;            % variance z3(E): \sig_n for expansions 
PARAMS(8)   = 2*PARAMS(7);     % variance z3(R): \sig_n for recessions; switch between 1 and 2 for effect of change in aggregate risk
PARAMS(9)   = 0.5;             % variance noise supply: \sigma_x ; robustness to value of 1.00
PARAMS(10)  = 0.10;             % frac of low returns to repeat for recessions
PARAMS(11)  = 15;              % \mu_1, \mu_2, \mu_3
PARAMS(12)  = 15;              % \bar{x}_3; robustness to value of 20
PARAMS(13)  = 1;               % K; robustness to value of 0.50

%%%%%%%%%%%%%%%%%%%%%%%%%%%% COMPUTE RESULTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% compute results
RESULTS     = RTMFAA_res(PARAMS, PARAMS_fix, PARAMS_sim);

% report results 

{ -999 'R' 'E'; ...
'\sigma_a' PARAMS(8) PARAMS(7); ...
'rho' PARAMS(3) PARAMS(2) }
RESULTS.aa
RESULTS.cm

% disp('Results (R all, R skilled, R unskilled, E all, E skilled, E unskilled)')
% RESULTS.t1;
% RESULTS.t2;

disp('Attention allocated to aggregate risk in R and E')
RESULTS.aa(3,:)
disp('Dispersion in R and E')
[RESULTS.p4(1) RESULTS.p4(4)]
disp('Performance in R and E')
[RESULTS.p6(1) RESULTS.p6(4)]       