% This program computes summary statistics for assets. 
% You can only vary one parameters over the rows. Columns are for the
% three assets
clear results rsq alphas betas idiovol;

for i = 1:3
    results      = ols(real_return(:,i)-(r-1),[ones(length(mkt_return),1), mkt_return-(r-1)]);
    rsq(1,i)     = results.rsqr;
    alphas(1,i)  = results.beta(1);
    betas(1,i)   = results.beta(2);
    idiovol(1,i) = results.sige^(1/2);
end

if boom ==1, %expansion
    
    % Average cross-section standard deviation on the return on assets 1 and 2
    ba_tss_return = mean(std(real_return(:,1:2)));
    
    % Average beta of assets 1 and 2
    ba_avg_beta = mean(betas(1:2));
    
    % Average cross-sectional standard deviation of the betas for assets 1 and 2
    ba_std_beta = std(betas(1:2));
    
    % Other results (old code)
    ba_tsa_avg_return = mean(mean(real_return(:,1:2)));
    ba_tsa_std_return = mean(std(real_return(:,1:2)'));
    ba_tss_std_return = std(std(real_return(:,1:2)));
    ba_avg_alpha      = mean(alphas(1:2));
    ba_std_alpha      = std(alphas(1:2));
    ba_avg_idiovol    = mean(idiovol(1:2));
    ba_std_idiovol    = std(idiovol(1:2));
    ba_avg_rsq        = mean(rsq(1:2));
    ba_std_rsq        = std(rsq(1:2));
    b_syst_risk       = mean(betas.^2*var(mkt_return));
    
else %recession
    
    % Average cross-section standard deviation on the return on assets 1 and 2
    ra_tss_return = mean(std(real_return(:,1:2)));
    
    % Average beta of assets 1 and 2
    ra_avg_beta = mean(betas(1:2));
    
    % Average cross-sectional standard deviation of the betas for assets 1 and 2
    ra_std_beta = std(betas(1:2));
    
    % Other results (old code)
    ra_tsa_avg_return = mean(mean(real_return(:,1:2)));
    ra_tsa_std_return = mean(std(real_return(:,1:2)'));
    ra_tss_std_return = std(std(real_return(:,1:2)));
    ra_avg_alpha = mean(alphas(1:2));
    ra_std_alpha = std(alphas(1:2));
    ra_avg_idiovol = mean(idiovol(1:2));
    ra_std_idiovol = std(idiovol(1:2));
    ra_avg_rsq = mean(rsq(1:2));
    ra_std_rsq = std(rsq(1:2));
    r_syst_risk = mean(betas.^2*var(mkt_return));
end

% Summarize results once you have them for both booms and recessions
if boom==2,
    asset_table      = nan(13,2);
    asset_table(1,:) = [ra_tsa_avg_return, ba_tsa_avg_return];
    asset_table(3,:) = [ra_tss_return, ba_tss_return];    
    asset_table(5,:) = [ra_avg_alpha, ba_avg_alpha];
    asset_table(7,:) = [ra_avg_beta, ba_avg_beta]/100;
    asset_table(9,:) = [ra_avg_idiovol, ba_avg_idiovol];
    asset_table(11,:) = [ra_avg_rsq, ba_avg_rsq];
    
    asset_table(2,:) = [ra_tsa_std_return, ba_tsa_std_return];
    asset_table(4,:) = [ra_tss_std_return, ba_tss_std_return];    
    asset_table(6,:) = [ra_std_alpha, ba_std_alpha];
    asset_table(8,:) = [ra_std_beta, ba_std_beta]/100;
    asset_table(10,:) = [ra_std_idiovol, ba_std_idiovol];
    asset_table(12,:) = [ra_std_rsq, ba_std_rsq];
    asset_table(13,:) = [r_syst_risk b_syst_risk];
    
    asset_table = asset_table.*100;
end