% This file computes Ftiming, Timing, Fpicking and Picking

cutlo   = [1, 1, lastinf+1];
cuthi   = [funds*0.8, lastinf, funds*0.8];

% Dev of fund weight from market weight. One matrix for each asset. Note 
% that I'm using the firm value weights that include the riskfree rate.
dweight1 = vw(:,:,1) - vwm(:,1)*ones(1,funds); % (draws x funds)
dweight2 = vw(:,:,2) - vwm(:,2)*ones(1,funds); % (draws x funds)
dweight3 = vw(:,:,3) - vwm(:,3)*ones(1,funds); % (draws x funds)

% Adjust dweight1, _2, _3 for the recession state when we add extra low 
% realizations of returns. Also adjust shocks. 
if length(mkt_return)>draws, % this is true when boom==2 (recession)  
    dwsort1     = dweight1(mktind,:); 
    dwsort2     = dweight2(mktind,:); 
    dwsort3     = dweight3(mktind,:); 
    dweight1    = [dweight1; dwsort1(1:round(draws*truncate),:)];
    dweight2    = [dweight2; dwsort2(1:round(draws*truncate),:)];
    dweight3    = [dweight3; dwsort3(1:round(draws*truncate),:)];
    shockssort  = shocks(mktind,:);
    shocks      = [shocks; shockssort(1:round(draws*truncate),:)];
end

% compute picking, timing, Ftiming, Fpicking for each fund
ermtx = [real_return(:,1)-betas(1)*mkt_return, ...
         real_return(:,2)-betas(2)*mkt_return, ...
         real_return(:,3)-betas(3)*mkt_return];
mktmtx = mkt_return*betas;
for j = 1:funds
    dweight_mtx = [dweight1(:,j) dweight2(:,j) dweight3(:,j)];
    Ftiming(1,j) = mean(sum( dweight_mtx.*...
                        repmat(shocks(:,3),1,3), 1 )./size(dweight_mtx,1));
    timing(1,j) = mean( sum( dweight_mtx.*mktmtx, 2 ) );
    Fpicking(1,j) = mean( sum( dweight_mtx(:,1:2).*shocks(:,1:2), 2 )./2 );
    picking(1,j) = mean( sum( dweight_mtx(:,1:2).*ermtx(:,1:2), 2 ) );                                                            
end


% Summary results by group
for group = 1:3,
    % group 1 is the first 80% of funds
    % group 2 is the informed funds
    % group 3 is the uninformed funds 
    % means by group
    moments(1,group) = mean(Ftiming(cutlo(group):cuthi(group)))*1000;
    moments(2,group) = mean(timing(cutlo(group):cuthi(group)))*10000;
    moments(3,group) = mean(Fpicking(cutlo(group):cuthi(group)))*1000;
    moments(4,group) = mean(picking(cutlo(group):cuthi(group)))*10000;   
end
